==> ruff_0.0.291+dfsg1.orig.tar.gz: ruff_0.0.291+dfsg1.orig/crates/ruff_linter/resources/test/fixtures/flake8_import_conventions/custom.py <==
import math  # not checked

import altair  # unconventional
import dask.array  # unconventional
import dask.dataframe  # unconventional
import matplotlib.pyplot  # unconventional
import numpy  # unconventional
import pandas  # unconventional
import seaborn  # unconventional
import tensorflow  # unconventional
import holoviews  # unconventional
import panel  # unconventional
import plotly.express  # unconventional
import matplotlib  # unconventional
import polars  # unconventional
import pyarrow  # unconventional

import altair as altr  # unconventional
import matplotlib.pyplot as plot  # unconventional
import dask.array as darray  # unconventional
import dask.dataframe as ddf  # unconventional
import numpy as nmp  # unconventional
import pandas as pdas  # unconventional
import seaborn as sbrn  # unconventional
import tensorflow as tfz  # unconventional
import holoviews as hsv  # unconventional
import panel as pns  # unconventional
import plotly.express as pltx  # unconventional
import matplotlib as ml  # unconventional
import polars as ps # unconventional
import pyarrow as arr  # unconventional

import altair as alt  # conventional
import dask.array as da  # conventional
import dask.dataframe as dd  # conventional
import matplotlib.pyplot as plt  # conventional
import numpy as np  # conventional
import pandas as pd  # conventional
import seaborn as sns  # conventional
import tensorflow as tf # conventional
import holoviews as hv  # conventional
import panel as pn  # conventional
import plotly.express as px  # conventional
import matplotlib as mpl  # conventional
import polars as pl # conventional
import pyarrow as pa  # conventional

from tensorflow.keras import Model  # conventional

==> ruff-0.13.0.tar.gz: ruff-0.13.0/crates/ruff_linter/resources/test/fixtures/flake8_import_conventions/custom.py <==
import math  # not checked

import altair  # unconventional
import dask.array  # unconventional
import dask.dataframe  # unconventional
import matplotlib.pyplot  # unconventional
import numpy  # unconventional
import pandas  # unconventional
import seaborn  # unconventional
import tensorflow  # unconventional
import holoviews  # unconventional
import panel  # unconventional
import plotly.express  # unconventional
import matplotlib  # unconventional
import polars  # unconventional
import pyarrow  # unconventional

import altair as altr  # unconventional
import matplotlib.pyplot as plot  # unconventional
import dask.array as darray  # unconventional
import dask.dataframe as ddf  # unconventional
import numpy as nmp  # unconventional
import pandas as pdas  # unconventional
import seaborn as sbrn  # unconventional
import tensorflow as tfz  # unconventional
import holoviews as hsv  # unconventional
import panel as pns  # unconventional
import plotly.express as pltx  # unconventional
import matplotlib as ml  # unconventional
import polars as ps # unconventional
import pyarrow as arr  # unconventional

import altair as alt  # conventional
import dask.array as da  # conventional
import dask.dataframe as dd  # conventional
import matplotlib.pyplot as plt  # conventional
import numpy as np  # conventional
import pandas as pd  # conventional
import seaborn as sns  # conventional
import tensorflow as tf # conventional
import holoviews as hv  # conventional
import panel as pn  # conventional
import plotly.express as px  # conventional
import matplotlib as mpl  # conventional
import polars as pl # conventional
import pyarrow as pa  # conventional

from tensorflow.keras import Model  # conventional

import numpy.typing  # unconventional
import numpy.typing as nt  # unconventional
import numpy.typing as npt  # conventional
